@@ -267,7 +267,7 @@ QVariant PDFOverviewModel::data ( const QModelIndex & index, int role) const{
 		}
 		return cache[index.row()];
 	case Qt::BackgroundColorRole:
-		return Qt::gray;
+        return QColor(Qt::gray);
 	}
 	return QVariant();
 }
@@ -457,13 +457,13 @@ PDFBaseSearchDock::PDFBaseSearchDock(PDFDocument* doc): QDockWidget(doc), docume
 	QMetaObject::connectSlotsByName(this);
 
 	// set texts
-	leFind->setToolTip(QApplication::translate("SearchReplace", "Text or pattern to search for", 0, QApplication::UnicodeUTF8));
-	bNext->setToolTip(QApplication::translate("SearchReplace", "Find next occurence", 0, QApplication::UnicodeUTF8));
-	bPrevious->setToolTip(QApplication::translate("SearchReplace", "Find previous occurence", 0, QApplication::UnicodeUTF8));
+    leFind->setToolTip(tr("Text or pattern to search for"));
+    bNext->setToolTip(tr("Find next occurence"));
+    bPrevious->setToolTip(tr("Find previous occurence"));
 
-	label->setText(QApplication::translate("SearchReplace", " Find :", 0, QApplication::UnicodeUTF8));
+    label->setText(tr(" Find :"));
 	label->setMinimumWidth(label->sizeHint().width());
-	cbCase->setText(QApplication::translate("SearchReplace", "Case", 0, QApplication::UnicodeUTF8));
+    cbCase->setText(tr("Case"));
 	cbCase->setMinimumWidth(cbCase->sizeHint().width());
 
 	minimum_width=frame_2->sizeHint().width()+leFind->sizeHint().width()+2*bNext->sizeHint().width()+5*hboxLayout->spacing();
@@ -890,12 +890,12 @@ void PDFClockDock::paintEvent(QPaintEvent * event){
 	QPainter p(this);
 	QRect r = rect();
 	p.fillRect(r, QColor::fromRgb(0,0,0));
-	p.fillRect(0, 0, r.width() * (start.secsTo(QDateTime::currentDateTime())) / qMax(start.secsTo(end), 1),  r.height() * 3 / 4,  QColor::fromRgb(255,0,0));
+    p.fillRect(0, 0, r.width() * (start.secsTo(QDateTime::currentDateTime())) / qMax(qint64(start.secsTo(end)), qint64(1) ),  r.height() * 3 / 4,  QColor::fromRgb(255,0,0));
 	p.fillRect(0, r.height() * 3 / 4, r.width() * document->widget()->getPageIndex() / qMax(1, document->widget()->realNumPages()-1),  r.height()/4, QColor::fromRgb(0,0,255));
 	QFont f = p.font();
 	f.setPixelSize(r.height());
 	QFontMetrics met(f);
-	QString rem = tr("%1min").arg(qMax(0,QDateTime::currentDateTime().secsTo(end)/60));
+    QString rem = tr("%1min").arg(qMax(qint64(0),qint64(QDateTime::currentDateTime().secsTo(end)/60)));
 	p.setFont(f);
 	p.setPen(QColor::fromRgb(255,255,255));
 	p.drawText(r, Qt::AlignRight | Qt::AlignVCenter, rem);
@@ -903,3 +903,42 @@ void PDFClockDock::paintEvent(QPaintEvent * event){
 
 
 #endif
+
+
+MessageFrame::MessageFrame(QWidget *parent) : QFrame(parent), label(0)
+{
+	QHBoxLayout *layout = new QHBoxLayout();
+	setLayout(layout);
+	label = new QLabel("test");
+	label->setWordWrap(true);
+	layout->addWidget(label);
+	layout->setContentsMargins(2, 2, 2, 2);
+
+	setStyleSheet("background: #FFFBBF;");
+	setVisible(false);
+}
+
+/*
+ * Displays the message frame with the given text.
+ *
+ * actions: For each action, a button with the text of the action is inserted into the message panel.
+ *          The action is triggered when the button is pressed.
+ *          The button takes ownership of the action.
+ */
+void MessageFrame::showText(const QString &text, QList<QAction *> actions) {
+	label->setText(text);
+
+	foreach (QPushButton *bt, buttons)
+		delete bt;
+	buttons.clear();
+
+	foreach (QAction *act, actions) {
+		QPushButton *bt = new QPushButton(act->text());
+		act->setParent(bt);
+		bt->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+		buttons.append(bt);
+		connect(bt, SIGNAL(clicked()), act, SIGNAL(triggered()));
+		layout()->addWidget(bt);
+	}
+	show();
+}
