@@ -30,7 +30,11 @@
 #include <QProgressDialog>
 
 //#include "FindDialog.h"
+#if QT_VERSION < 0x050000
 #include "poppler-qt4.h"
+#else
+#include "poppler-qt5.h"
+#endif
 #include "synctex_parser.h"
 
 #include "ui_PDFDocument.h"
@@ -49,6 +53,12 @@ class ConfigManagerInterface;
 class PDFDocument;
 class PDFWidget;
 
+class TitledPanel;
+class PDFAnnotations;
+class PDFAnnotation;
+class PDFAnnotationTableView;
+class MessageFrame;
+
 class PDFMagnifier : public QLabel
 {
 	Q_OBJECT
@@ -223,9 +233,11 @@ private:
 	void adjustSize();
 	void updateCursor();
 	void updateCursor(const QPoint& pos);
+	QRect mapPopplerRectToWidget(QRectF rect, const QSizeF &pageSize) const;
 	void useMagnifier(const QMouseEvent *inEvent);
 	void goToDestination(const Poppler::LinkDestination& dest);
 	void doLink(const Poppler::Link *link);
+	void annotationClicked(Poppler::Annotation *annotation, const QPointF &scaledPos);
 	void doZoom(const QPoint& clickPos, int dir, qreal newScaleFactor=1.0);
 
 	PDFScrollArea* getScrollArea();
@@ -292,7 +304,7 @@ private:
 	QList<int> pageHistory;
 	int pageHistoryIndex;
 
-    PDFDocument *pdfdocument;
+	PDFDocument *pdfdocument;
 };
 
 class PDFSearchResult {
@@ -367,6 +379,9 @@ protected:
 	virtual void closeEvent(QCloseEvent *event);
 	virtual void dragEnterEvent(QDragEnterEvent *event);
 	virtual void dropEvent(QDropEvent *event);
+	virtual void enterEvent(QEvent *event);
+	virtual void leaveEvent(QEvent *event);
+	void setToolbarsVisible(bool visible);
 
 public slots:
 	void reload(bool fillCache=true);
@@ -387,6 +402,7 @@ private slots:
 	void enableZoomActions(qreal);
 	void adjustScaleActions(autoScaleOption);
 	void syncClick(int page, const QPointF& pos, bool activate);
+	void stopReloadTimer();
 	void reloadWhenIdle();
 	void idleReload();
 
@@ -407,6 +423,8 @@ private slots:
 	void jumpToPage();
 
 	void search(bool backward, bool incremental);
+	void gotoAnnotation(const PDFAnnotation *ann);
+
 	void zoomFromAction();
 	void zoomSliderChange(int pos = 0);
     void enlarge();
@@ -416,6 +434,7 @@ signals:
 	void reloaded();
 	void syncSource(const QString& sourceFile, int line, bool activate, const QString& guessedWord); //view -> source
 	void syncView(const QString& pdfFile, const QFileInfo& masterFile, int page); //view -> other view
+	void focusEditor();
 	void fileDropped(const QUrl& url);
 
 	void runCommand(const QString& command, const QFileInfo& masterFile, const QFileInfo& currentFile, int linenr);
@@ -448,6 +467,12 @@ private:
 	
 	PDFWidget	*pdfWidget;
 	PDFScrollArea	*scrollArea;
+	MessageFrame *messageFrame;
+	TitledPanel * annotationPanel;
+	PDFAnnotations * annotations;
+	PDFAnnotationTableView * annotationTable;
+
+
 	QButtonGroup	*toolButtonGroup;
 	QToolButton *comboZoom;
 	QLineEdit *leCurrentPage;
