@@ -3,6 +3,7 @@
 
 #include <QByteArray>
 struct PDFDocumentConfig{
+	bool autoHideToolbars;
 	int windowLeft, windowTop;
 	int windowWidth, windowHeight;
 	bool windowMaximized;
@@ -19,14 +20,14 @@ struct PDFDocumentConfig{
 	int magnifierSize, magnifierShape;
 	bool magnifierBorder;
 
-
-
 	QString syncFileMask;
 
 
 //live options
+	int editTool;
 	bool continuous,singlepagestep;
 	bool followFromCursor, followFromScroll, syncViews;
+	bool invertColors;
 	int gridx,gridy;
 };
 
