@@ -10,16 +10,13 @@
  ***************************************************************************/
 
 #include "aboutdialog.h"
-
 #include "utilsVersion.h"
-extern const char* TEXSTUDIO_SVN_VERSION;
-
 
 AboutDialog::AboutDialog(QWidget *parent)
 		:QDialog(parent) {
 	ui.setupUi(this);
 	ui.textBrowser->setOpenExternalLinks(true);
-	ui.textBrowser->setHtml(QString("<b>%1 %2</b> (SVN %3)").arg(TEXSTUDIO).arg(TXSVERSION).arg(TEXSTUDIO_SVN_VERSION?TEXSTUDIO_SVN_VERSION:"??") + "<br>" +
+	ui.textBrowser->setHtml(QString("<b>%1 %2</b> (hg %3)").arg(TEXSTUDIO).arg(TXSVERSION).arg(TEXSTUDIO_HG_REVISION?TEXSTUDIO_HG_REVISION:"n/a") + "<br>" +
 				(IS_DEVELOPMENT_VERSION ? tr("<b>This is a development version.</b><br>") : "") +
 				tr("Using Qt Version %1, compiled with Qt %2 %3").arg(qVersion()).arg(QT_VERSION_STR).arg(COMPILED_DEBUG_OR_RELEASE) + "<br><br>" +
 				"Copyright (c)<br>" +
@@ -35,7 +32,7 @@ AboutDialog::AboutDialog(QWidget *parent)
 				tr("TeXstudio contains an image by Alexander Klink.")+"<br>"+
 				tr("TeXstudio uses icons from the Crystal Project (LGPL) and the Oxygen icon theme (CC-BY-SA 3.0).")+"<br>"+
 				"<br>"+
-                tr("Thanks to ")+QString::fromUtf8("Frédéric Devernay, Denis Bitouzé, Jean-Côme Charpentier, Luis Silvestre, Enrico Vittorini, Aleksandr Zolotarev, David Sichau, Grigory Mozhaev, mattgk, A. Weder, Pavel Fric, András Somogyi, István Blahota, Edson Henriques, Grant McLean, Tom Jampen, Kostas Oikinimou, Lion Guillaume, ranks.nl, AI Corleone, Diego Andrés Jarrín, Matthias Pospiech, Zulkifli Hidayat, Christian Spieß, Robert Diaz, Kirill Müller & Atsushi Nakajima.<br><br>")+
+				tr("Thanks to ")+QString::fromUtf8("Frédéric Devernay, Denis Bitouzé, Jean-Côme Charpentier, Luis Silvestre, Enrico Vittorini, Aleksandr Zolotarev, David Sichau, Grigory Mozhaev, mattgk, A. Weder, Pavel Fric, András Somogyi, István Blahota, Edson Henriques, Grant McLean, Tom Jampen, Kostas Oikinimou, Lion Guillaume, ranks.nl, AI Corleone, Diego Andrés Jarrín, Matthias Pospiech, Zulkifli Hidayat, Christian Spieß, Robert Diaz, Kirill Müller, Atsushi Nakajima Yuriy Kolerov, Victor Kozyakin, Mattia Meneguzzo & Andriy Bandura.<br><br>")+
 				tr("Project home site:") + " <a href=\"http://texstudio.sourceforge.net/\">http://texstudio.sourceforge.net/</a><br><br>"+
 				tr("This program is licensed to you under the terms of the GNU General Public License Version 2 as published by the Free Software Foundation."));
 	QAction* act = new QAction("large", this);
