@@ -41,7 +41,7 @@ public:
 	bool autodetectLoadedFile;
 	QStringList commonEncodings;
 
-	QHash<int, int> editorKeys;
+    QHash<QString, int> editorKeys;
 	QSet<int> editorAvailableOperations;
 
 	//build
@@ -63,7 +63,7 @@ public:
 	QString interfaceFontFamily;
 	bool useTexmakerPalette;
 	int interfaceFontSize;
-	bool tabbedLogView, newLeftPanelLayout;
+	bool newLeftPanelLayout;
 	bool mruDocumentChooser;
 	bool configShowAdvancedOptions, configRiddled;
 	bool centralVisible;
@@ -158,6 +158,8 @@ public:
 	
     // disable usage of esc for closing fullscreen view
     bool disableEscForClosingFullscreen;
+	bool goToErrorWhenDisplayingLog;
+	bool showLogMarkersWhenClickingLogEntry;
 
     // input unicode instead of latex command from symbolgrid (if available)
     bool insertUTF;
@@ -208,7 +210,6 @@ public:
 	void populateCustomActions(QListWidget* parent, QMenu* menu, bool go=false);
 
 signals:
-	void tabbedLogViewChanged(bool changed);
 	void newLeftPanelLayoutChanged(bool newValue);
 	void watchedMenuChanged(const QString& menuId);
 public:
