@@ -32,7 +32,7 @@ class LatexCompleterConfig;
 class LatexCompleter : public QObject  {
 	Q_OBJECT
 public:
-    enum CompletionFlag { CF_FORCE_VISIBLE_LIST = 1, CF_NORMAL_TEXT = 2, CF_FORCE_REF = 4, CF_OVERRIDEN_BACKSLASH=8,CF_FORCE_GRAPHIC = 16, CF_FORCE_CITE = 32};
+    enum CompletionFlag { CF_FORCE_VISIBLE_LIST = 1, CF_NORMAL_TEXT = 2, CF_FORCE_REF = 4, CF_OVERRIDEN_BACKSLASH=8,CF_FORCE_GRAPHIC = 16, CF_FORCE_CITE = 32, CF_FORCE_PACKAGE = 64};
 	Q_DECLARE_FLAGS(CompletionFlags, CompletionFlag);
 	
 	LatexCompleter(const LatexParser& latexParser, QObject *p = 0);
@@ -49,6 +49,8 @@ public:
 	
 	void setConfig(LatexCompleterConfig* config);
 	LatexCompleterConfig* getConfig() const;
+
+    void setPackageList(QSet<QString> *lst);
 	
 	QString lookupWord(QString id);
 	
@@ -82,6 +84,8 @@ private:
 	CompletionListModel* listModel;
 	directoryReader *dirReader;
 	QEditor *editor;
+
+    QSet<QString> *packageList;
 	
 	QWidget *widget;
 	QTabBar *tbBelow,*tbAbove;
@@ -99,6 +103,7 @@ private:
 	bool forcedRef;
 	bool forcedGraphic;
 	bool forcedCite;
+    bool forcedPackage;
     bool startedFromTriggerKey;
 	QString workingDir;
 	
