@@ -157,7 +157,7 @@ void LatexDocument::initClearStructure() {
 void LatexDocument::updateStructure() {
 	initClearStructure();
 	
-	patchStructure(0, lineCount());
+    patchStructure(0, -1);
 	
 	emit structureLost(this);
 }
@@ -278,8 +278,17 @@ inline bool isDefinitionArgument(const QString &arg) {
 }
 
 void LatexDocument::patchStructure(int linenr, int count) {
-	
+    //qDebug()<<"begin Patch"<<QTime::currentTime().toString("HH:mm:ss:zzz");
+    if(!parent->patchEnabled())
+        return;
+
 	if (!baseStructure) return;
+
+    bool recheckLabels=true;
+    if(count<0){
+        count=lineCount();
+        recheckLabels=false;
+    }
 	
 	emit toBeChanged();
 	
@@ -344,7 +353,7 @@ void LatexDocument::patchStructure(int linenr, int count) {
 			if(i>=0) elem=elem.left(i);
 			ltxCommands.possibleCommands["user"].remove(elem);
 			removedUserCommands << elem;
-			updateSyntaxCheck=true;
+            //updateSyntaxCheck=true;
 		}
 		if (mLabelItem.contains(dlh)) {
 			QList<ReferencePair> labels=mLabelItem.values(dlh);
@@ -524,7 +533,9 @@ void LatexDocument::patchStructure(int linenr, int count) {
 						def=1;
 				}
 				ltxCommands.possibleCommands["user"].insert(name);
-				addedUserCommands << name;
+                if(!removedUserCommands.removeAll(name)){
+                    addedUserCommands << name;
+                }
 				if(def==1){
 					QString helper=name;
 					for (int j=0; j<options; j++) {
@@ -547,7 +558,7 @@ void LatexDocument::patchStructure(int linenr, int count) {
 				}
 				mUserCommandList.insert(line(i).handle(),name);
 				// remove obsolete Overlays (maybe this can be refined
-				updateSyntaxCheck=true;
+                //updateSyntaxCheck=true;
 				continue;
 			}
 			// special treatment \def
@@ -560,14 +571,16 @@ void LatexDocument::patchStructure(int linenr, int count) {
 					//qDebug()<< name << ":"<< optionStr;
 					int options=optionStr.mid(1).toInt(); //returns 0 if conversion fails
 					ltxCommands.possibleCommands["user"].insert(name);
-					addedUserCommands << name;
+                    if(!removedUserCommands.removeAll(name)){
+                        addedUserCommands << name;
+                    }
 					for (int j=0; j<options; j++) {
 						if (j==0) name.append("{%<arg1%|%>}");
 						else name.append(QString("{%<arg%1%>}").arg(j+1));
 					}
 					mUserCommandList.insert(line(i).handle(),name);
 					// remove obsolete Overlays (maybe this can be refined
-					updateSyntaxCheck=true;
+                    //updateSyntaxCheck=true;
 				}
 				continue;
 			}
@@ -645,11 +658,13 @@ void LatexDocument::patchStructure(int linenr, int count) {
 					packagesHelper.replaceInStrings(QRegExp("^"),preambel);
 				}
 				QStringList packages;
-				foreach(const QString& elem,packagesHelper)
+                foreach(QString elem,packagesHelper){
+                    elem=elem.simplified();
 					if(latexParser.packageAliases.contains(elem))
 						packages << latexParser.packageAliases.values(elem);
 					else
 						packages << elem;
+                }
 
 				foreach(const QString& elem,packages){
 					if(!removedUsepackages.removeAll(elem))
@@ -715,13 +730,13 @@ void LatexDocument::patchStructure(int linenr, int count) {
                 removedIncludes.removeAll(fname);
                 mIncludedFilesList.insert(line(i).handle(),fname);
 				LatexDocument* dc=parent->findDocumentFromName(fname);
-                if(dc)	dc->setMasterDocument(this);
+                if(dc)	dc->setMasterDocument(this,recheckLabels);
                 else {
                     lstFilesToLoad << fname;
                     //parent->addDocToLoad(fname);
                 }
 
-				newInclude->valid = dc;
+                newInclude->valid = !fname.isEmpty();
 				newInclude->setLine(line(i).handle(), i);
 				newInclude->columnNumber = offset;
 				flatStructure << newInclude;
@@ -752,7 +767,6 @@ void LatexDocument::patchStructure(int linenr, int count) {
             parent->updateMasterSlaveRelations(this);
         }
 	}//for each line handle
-	
 	QVector<StructureEntry*> parent_level(latexParser.structureCommands.count());
     if(!isHidden()){
         mergeStructure(baseStructure, parent_level, flatStructure, linenr, count);
@@ -799,9 +813,10 @@ void LatexDocument::patchStructure(int linenr, int count) {
 	foreach(se,MapOfMagicComments.values())
 		delete se;
 	
+    bool updateLtxCommands=false;
 	if(!addedUsepackages.isEmpty() || !removedUsepackages.isEmpty() || !addedUserCommands.isEmpty() || !removedUserCommands.isEmpty()){
 		bool forceUpdate=!addedUserCommands.isEmpty() || !removedUserCommands.isEmpty();
-        updateCompletionFiles(forceUpdate);
+        updateLtxCommands=updateCompletionFiles(forceUpdate,false,true);
 	}
 	
 	if (bibTeXFilesNeedsUpdate)
@@ -819,20 +834,27 @@ void LatexDocument::patchStructure(int linenr, int count) {
                 elem->edView->updateCitationFormats();
         }
     }
-	
-	if (completerNeedsUpdate || bibTeXFilesNeedsUpdate)
+
+    if (completerNeedsUpdate || bibTeXFilesNeedsUpdate)
 		emit updateCompleter();
 
-	if(updateSyntaxCheck) {
-		foreach(LatexDocument* elem,getListOfDocs()){
+
+    if(updateSyntaxCheck || updateLtxCommands) {
+        //qDebug()<<"update ltx"<< QTime::currentTime().toString("HH:mm:ss:zzz");
+        if(edView){
+            edView->updateLtxCommands(true);
+            //qDebug()<<"update ltxcommands done"<< QTime::currentTime().toString("HH:mm:ss:zzz");
+        }
+        /*foreach(LatexDocument* elem,getListOfDocs()){
 			//getEditorView()->reCheckSyntax();//todo: signal
             if(elem->edView){
                 elem->edView->updateLtxCommands();
+                qDebug()<<"update ltxcommands done"<< QTime::currentTime().toString("HH:mm:ss:zzz");
 				elem->edView->reCheckSyntax();
             }
-		}
+        }*/
 	}
-	
+    //qDebug()<<"update View"<< QTime::currentTime().toString("HH:mm:ss:zzz");
 	//update view
 	if(edView)
 		edView->documentContentChanged(linenr, count);
@@ -845,6 +867,7 @@ void LatexDocument::patchStructure(int linenr, int count) {
     foreach(QString fname,lstFilesToLoad){
         parent->addDocToLoad(fname);
     }
+    //qDebug()<<"leave"<< QTime::currentTime().toString("HH:mm:ss:zzz");
 }
 
 #ifndef QT_NO_DEBUG
@@ -996,12 +1019,14 @@ QMultiHash<QDocumentLineHandle*,int> LatexDocument::getRefs(const QString& name)
 	return result;
 }
 
-void LatexDocument::setMasterDocument(LatexDocument* doc){
+void LatexDocument::setMasterDocument(LatexDocument* doc,bool recheck){
 	masterDocument=doc;
 	QList<LatexDocument *>listOfDocs=getListOfDocs();
-	foreach(LatexDocument *elem,listOfDocs){
-		elem->recheckRefsLabels();
-	}
+    if(recheck){
+        foreach(LatexDocument *elem,listOfDocs){
+            elem->recheckRefsLabels();
+        }
+    }
 }
 
 QList<LatexDocument *>LatexDocument::getListOfDocs(QSet<LatexDocument*> *visitedDocs){
@@ -1241,11 +1266,11 @@ StructureEntry* StructureEntryIterator::next(){
 
 LatexDocumentsModel::LatexDocumentsModel(LatexDocuments& docs):documents(docs),
   iconDocument(":/images/doc.png"), iconMasterDocument(":/images/masterdoc.png"), iconBibTeX(":/images/bibtex.png"), iconInclude(":/images/include.png"),
-  iconWarning(getRealIcon("warning")), m_singleMode(false){
+  iconWarning(getRealIconCached("warning")), m_singleMode(false){
   mHighlightIndex=QModelIndex();
   iconSection.resize(LatexParser::getInstance().structureCommands.count());
   for (int i=0;i<LatexParser::getInstance().structureCommands.count();i++)
-    iconSection[i]=getRealIcon(LatexParser::getInstance().structureCommands[i].mid(1));
+    iconSection[i]=getRealIconCached(LatexParser::getInstance().structureCommands[i].mid(1));
 }
 Qt::ItemFlags LatexDocumentsModel::flags ( const QModelIndex & index ) const{
 	if (index.isValid()) return Qt::ItemIsEnabled|Qt::ItemIsSelectable;
@@ -1313,12 +1338,12 @@ QVariant LatexDocumentsModel::data ( const QModelIndex & index, int role) const{
 		default: return QVariant();
 		}
 	case Qt::BackgroundRole:
-		if (index==mHighlightIndex) return QVariant(Qt::lightGray);
+        if (index==mHighlightIndex) return QVariant(QColor(Qt::lightGray));
 		if (entry->appendix) return QVariant(QColor(200,230,200));
 		else return QVariant();
 	case Qt::ForegroundRole:
-		if((entry->type==StructureEntry::SE_INCLUDE) && (entry->valid)) {
-			return QVariant(Qt::red);
+        if(entry->type==StructureEntry::SE_INCLUDE) {
+            return entry->valid ? QVariant() : QVariant(QColor(Qt::red)); // not found files marked red, else black (green is not easily readable)
 		}else return QVariant();
 	case Qt::FontRole:
 		if(entry->type==StructureEntry::SE_DOCUMENT_ROOT) {
@@ -1397,8 +1422,8 @@ QModelIndex LatexDocumentsModel::parent ( const QModelIndex & index ) const{
 			break;
 		}
 	if (!found) entry->debugPrint("No document for entry:");
-	Q_ASSERT(found);
-	Q_ASSERT(entry->document == found);
+	//Q_ASSERT(found);
+	//Q_ASSERT(entry->document == found);
 #endif
 	if (!entry) return QModelIndex();
 	if (!entry->parent) return QModelIndex();
@@ -1473,8 +1498,18 @@ void LatexDocumentsModel::setHighlightedEntry(StructureEntry* entry){
 }
 
 void LatexDocumentsModel::resetAll(){
+#if QT_VERSION<0x050000
+#else
+    beginResetModel();
+#endif
+
 	mHighlightIndex=QModelIndex();
-	reset();
+
+#if QT_VERSION<0x050000
+    reset();
+#else
+    endResetModel();
+#endif
 }
 
 void LatexDocumentsModel::resetHighlight(){
@@ -1557,6 +1592,7 @@ LatexDocuments::LatexDocuments(): model(new LatexDocumentsModel(*this)), masterD
 	showLineNumbersInStructure=false;
 	indentationInStructure=-1;
 	indentIncludesInStructure=0;
+    m_patchEnabled=true;
 }
 
 LatexDocuments::~LatexDocuments(){
@@ -1837,7 +1873,7 @@ bool LatexDocuments::singleMode() const {
 
 void LatexDocuments::updateBibFiles(bool updateFiles){
   mentionedBibTeXFiles.clear();
-  foreach (LatexDocument* doc, documents) {
+  foreach (LatexDocument* doc, getDocuments() ) {
     if(updateFiles){
       QMultiHash<QDocumentLineHandle*,FileNamePair>::iterator it = doc->mentionedBibTeXFiles().begin();
       QMultiHash<QDocumentLineHandle*,FileNamePair>::iterator itend = doc->mentionedBibTeXFiles().end();
@@ -2109,12 +2145,14 @@ void LatexDocument::parseMagicComment(const QString &name, const QString &val, S
 		se->tooltip = QString();
 		se->valid = false;
 	}
+	QString lowerName = name.toLower();
 
-	if (name.toLower() == "spellcheck") {
+
+	if (lowerName == "spellcheck") {
 		mSpellingDictName = val;
 		emit spellingDictChanged(mSpellingDictName);
 		se->valid = true;
-	} else if ((name.toLower() == "texroot")||(name.toLower() == "root")){
+	} else if ((lowerName == "texroot")||(lowerName == "root")){
 		QString fname=findFileName(val);
 		LatexDocument* dc=parent->findDocumentFromName(fname);
 		if(dc)	setMasterDocument(dc);
@@ -2122,9 +2160,9 @@ void LatexDocument::parseMagicComment(const QString &name, const QString &val, S
 			parent->addDocToLoad(fname);
 		}
 		se->valid = true;
-	} else if (name.toLower() == "encoding") {
+	} else if (lowerName == "encoding") {
 		bool hasUndo = canUndo();
-		QTextCodec *codec = QTextCodec::codecForName(val.toAscii());
+		QTextCodec *codec = QTextCodec::codecForName(val.toLatin1());
 		if (!codec) {
 			se->tooltip = tr("Invalid codec");
 			return;
@@ -2132,6 +2170,10 @@ void LatexDocument::parseMagicComment(const QString &name, const QString &val, S
 		setCodec(codec);
 		if (!hasUndo) clearUndo(); // changing the codec pushes an entry to the undo/redo stack we don't want this for the first parsing at loading
 		se->valid = true;
+	} else if (lowerName == "txs-script") {
+		se->valid = true;
+	} else if (lowerName == "program" || lowerName.startsWith("program:")) {
+		se->valid = true;
 	} else {
 		se->tooltip = tr("Unknown magic comment");
 		return;
@@ -2210,15 +2252,15 @@ void LatexDocuments::bibTeXFilesNeedUpdate(){
 	bibTeXFilesModified=true;
 }
 
-void LatexDocuments::updateMasterSlaveRelations(LatexDocument *doc){
+void LatexDocuments::updateMasterSlaveRelations(LatexDocument *doc, bool recheckRefs){
 	//update Master/Child relations
 	//remove old settings ...
-	doc->setMasterDocument(0);
+    doc->setMasterDocument(0,false);
     QList<LatexDocument*> docs=getDocuments();
     foreach(LatexDocument* elem,docs){
 		if(elem->getMasterDocument()==doc){
-			elem->setMasterDocument(0);
-			elem->recheckRefsLabels();
+            elem->setMasterDocument(0,recheckRefs);
+            //elem->recheckRefsLabels();
 		}
 	}
 	
@@ -2229,7 +2271,7 @@ void LatexDocuments::updateMasterSlaveRelations(LatexDocument *doc){
 			continue;
 		QStringList includedFiles=elem->includedFiles();
 		if(includedFiles.contains(fname)){
-			doc->setMasterDocument(elem);
+            doc->setMasterDocument(elem,recheckRefs);
             break;
 		}
 	}
@@ -2239,15 +2281,16 @@ void LatexDocuments::updateMasterSlaveRelations(LatexDocument *doc){
 	foreach(const QString& fname,includedFiles){
 		LatexDocument* child=this->findDocumentFromName(fname);
 		if(child){
-			child->setMasterDocument(doc);
+            child->setMasterDocument(doc,recheckRefs);
 			LatexEditorView *edView=child->getEditorView();
-			if(edView)
+            if(edView && recheckRefs)
 				edView->reCheckSyntax(); // redo syntax checking (in case of defined commands)
 		}
 	}
 	
 	//recheck references
-	doc->recheckRefsLabels();
+    if(recheckRefs)
+        doc->recheckRefsLabels();
 }
 
 const LatexDocument* LatexDocument::getTopMasterDocument(QSet<const LatexDocument*> *visitedDocs) const {
@@ -2301,7 +2344,7 @@ QSet<QString> LatexDocument::additionalCommandsList(){
     return pck.completionWords.toSet();
 }
 
-void LatexDocument::updateCompletionFiles(bool forceUpdate,bool forceLabelUpdate){
+bool LatexDocument::updateCompletionFiles(bool forceUpdate,bool forceLabelUpdate,bool delayUpdate){
 
     QStringList files=mUsepackageList.values();
 	bool update=forceUpdate;
@@ -2336,7 +2379,7 @@ void LatexDocument::updateCompletionFiles(bool forceUpdate,bool forceLabelUpdate
 	//patch lines for new commands (ref,def, etc)
 	LatexParser& latexParser = LatexParser::getInstance();
 	QStringList categories;
-	categories<< "%ref" << "%label" << "%definition" << "%cite" << "%usepackage" << "%graphics" << "%file" << "%bibliography" << "%include";
+    categories<< "%ref" << "%label" << "%definition" << "%cite" << "%citeExtended" << "%citeExtendedCommand" << "%usepackage" << "%graphics" << "%file" << "%bibliography" << "%include";
 	QStringList newCmds;
 	foreach(const QString elem,categories){
 		QStringList cmds=ltxCommands.possibleCommands[elem].values();
@@ -2351,15 +2394,21 @@ void LatexDocument::updateCompletionFiles(bool forceUpdate,bool forceLabelUpdate
 		patchLinesContaining(newCmds);
 	}
 	
+    if(delayUpdate)
+        return update;
+
 	if(update){
-		foreach(LatexDocument* elem,getListOfDocs()){
+        LatexEditorView *edView=getEditorView();
+        edView->updateLtxCommands(true);
+        /*foreach(LatexDocument* elem,getListOfDocs()){
 			LatexEditorView *edView=elem->getEditorView();
 			if(edView){
 				edView->updateLtxCommands();
 				edView->reCheckSyntax();
 			}
-		}
+        }*/
 	}
+    return false;
 }
 
 void LatexDocument::gatherCompletionFiles(QStringList &files,QStringList &loadedFiles,LatexPackage &pck){
@@ -2535,6 +2584,14 @@ void LatexDocument::patchLinesContaining(const QStringList cmds){
   }
 }
 
+void LatexDocuments::enablePatch(const bool enable){
+    m_patchEnabled=enable;
+}
+
+bool LatexDocuments::patchEnabled(){
+    return m_patchEnabled;
+}
+
 QString LatexDocuments::findPackageByCommand(const QString command){
     // go through all cached packages (cwl) and find command in one of them
     QString result;
