@@ -91,9 +91,14 @@ public:
     bool containsBibTeXId(QString id);
 
     void updateCitationFormats();
+    void updatePackageFormats();
 	
+	void clearLogMarks();
+	void addLogEntry(int logEntryNumber, int lineNumber, int markID);
+	void setLogMarksVisible(bool visible);
 	QMultiHash<QDocumentLineHandle*, int> lineToLogEntries;
 	QHash<int, QDocumentLineHandle*> logEntryToLine;
+	QHash<int, int> logEntryToMarkID;
 	
 	static int hideTooltipWhenLeavingLine;
 	
@@ -125,6 +130,10 @@ public:
 	static void selectOptionInLatexArg(QDocumentCursor &cur);
     void getEnv(int lineNumber,StackEnvironment &env); // get Environment for syntax checking, number of cols is now part of env
 	QDocumentCursor parenthizedTextSelection(const QDocumentCursor &cursor, bool includeParentheses=true);
+    void setLatexPackageList(QSet<QString> *lst){
+        latexPackageList=lst;
+    }
+
 private:
 	QAction *lineNumberPanelAction, *lineMarkPanelAction, *lineFoldPanelAction, *lineChangePanelAction, 
 	*statusPanelAction, *searchReplacePanelAction, *gotoLinePanelAction;
@@ -137,11 +146,14 @@ private:
 	QPoint m_point;
 	
 	static int environmentFormat,referencePresentFormat,referenceMissingFormat,referenceMultipleFormat, citationMissingFormat, citationPresentFormat,structureFormat,
+	packagePresentFormat,packageMissingFormat,packageUndefinedFormat,
 	wordRepetitionFormat, wordRepetitionLongRangeFormat, badWordFormat, grammarMistakeFormat, grammarMistakeSpecial1Format, grammarMistakeSpecial2Format, grammarMistakeSpecial3Format, grammarMistakeSpecial4Format,
 	numbersFormat, verbatimFormat, pictureFormat, pweaveDelimiterFormat, pweaveBlockFormat, sweaveDelimiterFormat, sweaveBlockFormat, math_DelimiterFormat;
 	static QList<int> grammarFormats;
 	static QVector<bool> grammarFormatsDisabled;
 	static QList<int> formatsList;
+
+    QSet<QString> *latexPackageList;
 	
 	friend class DefaultInputBinding;
 	friend class SyntaxCheckTest;
@@ -209,7 +221,8 @@ public slots:
 	void insertHardLineBreaks(int newLength, bool smartScopeSelection, bool joinLines);
 	void viewActivated();
 	void clearOverlays();
-	void updateLtxCommands();
+    void updateLtxCommands(bool updateAll=false);
+    void setLtxCommands(const LatexParser& cmds);
 	void paste();
     void insertMacro(QString macro, const QRegExp& trigger = QRegExp(), int triggerId = 0, bool allowWrite=false);
 
