@@ -8,17 +8,12 @@ LatexStyleParser::LatexStyleParser(QObject *parent,QString baseDirName,QString k
     kpseWhichCmd=kpsecmd;
     mFiles.clear();
     //check if pdflatex is present
-//#ifndef Q_WS_WIN
     texdefDir=kpsecmd.left(kpsecmd.length()-9);
     QProcess myProc(0);
     //myProc.start(texdefDir+"texdef");
     myProc.start(texdefDir+"pdflatex -v");
     myProc.waitForFinished();
     texdefMode=(myProc.exitCode()==0);
-//#else
-//    texdefMode=false;
-    //miktex always has a texdef.exe present even if texdef is not installed or no working perl is present. Furthermore the call from txs does not seem to work properly with miktex
-//#endif
 }
 
 void LatexStyleParser::stop(){
@@ -45,12 +40,12 @@ void LatexStyleParser::run(){
             topPackage=fn;
             topPackage.chop(4);
         }
-		QString fullName=kpsewhich(fn); // find file
-		if(fullName.isEmpty())
-		    continue;
+	QString fullName=kpsewhich(fn); // find file
+	if(fullName.isEmpty())
+	    continue;
 
-		QStringList results;
-        results=readPackage(fullName); // parse package(s)
+	QStringList results,parsedPackages;
+	results=readPackage(fullName,parsedPackages); // parse package(s)
         results.sort();
 
         if(texdefMode){
@@ -84,7 +79,7 @@ void LatexStyleParser::run(){
                     if(result.startsWith(td)){
                         if(result.length()>td.length()){
                             QChar c=result.at(td.length());
-                            switch(c.toAscii()){
+                            switch(c.toLatin1()){
                             case '#':;
                             case '{':;
                             case '[':addCommand=false;
@@ -152,11 +147,14 @@ void LatexStyleParser::addFile(QString filename){
 	mFilesAvailable.release();
 }
 
-QStringList LatexStyleParser::readPackage(QString fn){
+QStringList LatexStyleParser::readPackage(QString fn,QStringList& parsedPackages){
+    if(parsedPackages.contains(fn))
+	return QStringList();
     QFile data(fn);
     QStringList results;
     if(data.open(QIODevice::ReadOnly | QIODevice::Text)){
         QTextStream stream(&data);
+	parsedPackages<<fn;
         QString line;
         QRegExp rxDef("\\\\def\\s*(\\\\[\\w@]+)\\s*(#\\d+)?");
         QRegExp rxCom("\\\\(newcommand|providecommand)\\*?\\s*\\{(\\\\\\w+)\\}\\s*\\[?(\\d+)?\\]?");
@@ -258,7 +256,7 @@ QStringList LatexStyleParser::readPackage(QString fn){
                 QString name=rxInput.cap(1);
                 name=kpsewhich(name);
                 if(!name.isEmpty() && name!=fn) // avoid indefinite loops
-                    results << readPackage(name);
+		    results << readPackage(name,parsedPackages);
                 continue;
             }
             if(rxNewLength.indexIn(line)>-1){
@@ -310,6 +308,8 @@ QStringList LatexStyleParser::readPackage(QString fn){
 }
 
 QString LatexStyleParser::kpsewhich(QString name){
+    if(name.startsWith("."))
+	return "";  // don't check .sty/.cls
     QString fn=name;
     if(!kpseWhichCmd.isEmpty()){
 	QProcess myProc(0);
