@@ -34,26 +34,26 @@
 #include <QtCore/QDebug>
 #include <QtCore/QLibrary>
 
-#include <QtGui/QApplication>
-#include <QtGui/QComboBox>
-#include <QtGui/QDialog>
-#include <QtGui/QDialogButtonBox>
-#include <QtGui/QDockWidget>
-#include <QtGui/QLabel>
-#include <QtGui/QLineEdit>
-#include <QtGui/QMainWindow>
-#include <QtGui/QMenuBar>
-#include <QtGui/QPainter>
-#include <QtGui/QPixmap>
-#include <QtGui/QPixmapCache>
-#include <QtGui/QPushButton>
-#include <QtGui/QScrollArea>
-#include <QtGui/QSplitter>
-#include <QtGui/QStatusBar>
-#include <QtGui/QStyleFactory>
-#include <QtGui/QStyleOption>
-#include <QtGui/QToolBar>
-#include <QtGui/QToolButton>
+#include <QApplication>
+#include <QComboBox>
+#include <QDialog>
+#include <QDialogButtonBox>
+#include <QDockWidget>
+#include <QLabel>
+#include <QLineEdit>
+#include <QMainWindow>
+#include <QMenuBar>
+#include <QPainter>
+#include <QPixmap>
+#include <QPixmapCache>
+#include <QPushButton>
+#include <QScrollArea>
+#include <QSplitter>
+#include <QStatusBar>
+#include <QStyleFactory>
+#include <QStyleOption>
+#include <QToolBar>
+#include <QToolButton>
 #include "utilsSystem.h"
 
 #if QT_VERSION >= 0x040500
@@ -126,7 +126,11 @@ public:
 };
 
 ManhattanStyle::ManhattanStyle(const QString &baseStyleName)
+#if QT_VERSION<0x050000
     : QWindowsStyle(), d(new ManhattanStylePrivate(baseStyleName))
+#else
+    : QProxyStyle(), d(new ManhattanStylePrivate(baseStyleName))
+#endif
 {
 }
 
