@@ -5,7 +5,11 @@
 
 #include "smallUsefulFunctions.h"
 
+#if QT_VERSION < 0x050000
 #include "poppler-qt4.h"
+#else
+#include "poppler-qt5.h"
+#endif
 
 #include <QThread>
 #include <QSemaphore>
