@@ -322,8 +322,8 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		static inline const QList<QEditor*>& editors() { return m_editors; }		
 
 		static QString translateEditOperation(const EditOperation& op);
-		static void setEditOperations(const QHash<int, int>& newOptions, bool mergeWithDefault=false);
-		static QHash<int, int> getEditOperations(bool excludeDefault=false);
+        static void setEditOperations(const QHash<QString, int>& newOptions, bool mergeWithDefault=false);
+        static QHash<QString, int> getEditOperations(bool excludeDefault=false);
 		static QSet<int> getAvailableOperations();
 		static void registerEditOperation(const EditOperation& op);
 		static void addEditOperation(const EditOperation& op, const Qt::KeyboardModifiers& modifiers, const Qt::Key& key);
@@ -473,6 +473,7 @@ public slots:
 		void setContentClean(bool y);
 		
 		void emitCursorPositionChanged();
+		void ensureCursorVisible(const QDocumentCursor& cursor, MoveFlags mflags = NoFlags);
 		void ensureCursorVisible(MoveFlags mflags = NoFlags);
 		
 		virtual void setContentModified(bool y);
@@ -621,7 +622,7 @@ public slots:
 		bool m_selection;
 		QRect m_crect, m_margins;
 		QPoint m_clickPoint, m_dragPoint;
-		QBasicTimer m_blink, m_scroll, m_click, m_drag;
+		QBasicTimer m_blink, m_click, m_drag;
 
 		bool mDisplayModifyTime;
 		
@@ -634,9 +635,9 @@ public slots:
 		static QHash<QString, QEditorInputBindingInterface*> m_registeredBindings;
 		
 		static bool m_defaultKeysSet;
-		static QHash<int, int> m_registeredKeys;
+        static QHash<QString, int> m_registeredKeys;
 		static QSet<int> m_registeredOperations;
-		static QHash<int, int> m_registeredDefaultKeys;
+        static QHash<QString, int> m_registeredDefaultKeys;
 
 		static int m_manageMenu;
 
