@@ -88,7 +88,7 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	bClose->setObjectName(("bClose"));
 	bClose->setMinimumSize(buttonSize);
 	bClose->setMaximumSize(buttonSize);
-    bClose->setIcon(getRealIcon("fileclose"));
+    bClose->setIcon(getRealIconCached("fileclose"));
 	gridLayout->addWidget(bClose, 0, 0, 1, 1);
 
 	QLabel* lbFind = new QLabel(this);
@@ -112,21 +112,21 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	bNext->setObjectName(("bNext"));
 	bNext->setMinimumSize(buttonSize);
 	bNext->setMaximumSize(buttonSize);
-    bNext->setIcon(getRealIcon("down"));
+    bNext->setIcon(getRealIconCached("down"));
 	gridLayout->addWidget(bNext, 0, 3, 1, 1);
 
 	bPrevious = new QToolButton(this);
 	bPrevious->setObjectName(("bPrevious"));
 	bPrevious->setMinimumSize(buttonSize);
 	bPrevious->setMaximumSize(buttonSize);
-    bPrevious->setIcon(getRealIcon("up"));
+    bPrevious->setIcon(getRealIconCached("up"));
 	gridLayout->addWidget(bPrevious, 0, 4, 1, 1);
 
 	bCount = new QToolButton(this);
 	bCount->setObjectName(("bCount"));
 	bCount->setMinimumSize(buttonSize);
 	bCount->setMaximumSize(buttonSize);
-    bCount->setIcon(getRealIcon("count"));
+    bCount->setIcon(getRealIconCached("count"));
 	gridLayout->addWidget(bCount, 0, 5, 1, 1);
 
 	QFrame *frameFindOptions = new QFrame(this);
@@ -211,21 +211,21 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	bReplaceNext->setObjectName(("bReplaceNext"));
 	bReplaceNext->setMinimumSize(buttonSize);
 	bReplaceNext->setMaximumSize(buttonSize);
-    bReplaceNext->setIcon(getRealIcon("replacedown"));
+    bReplaceNext->setIcon(getRealIconCached("replacedown"));
 	gridLayout->addWidget(bReplaceNext, 1, 3, 1, 1);
 
 	bReplacePrevious = new QToolButton(this);
 	bReplacePrevious->setObjectName(("bReplacePrevious"));
 	bReplacePrevious->setMinimumSize(buttonSize);
 	bReplacePrevious->setMaximumSize(buttonSize);
-    bReplacePrevious->setIcon(getRealIcon("replaceup"));
+    bReplacePrevious->setIcon(getRealIconCached("replaceup"));
 	gridLayout->addWidget(bReplacePrevious, 1, 4, 1, 1);
 
 	bReplaceAll = new QToolButton(this);
 	bReplaceAll->setObjectName(("bReplaceAll"));
 	bReplaceAll->setMinimumSize(buttonSize);
 	bReplaceAll->setMaximumSize(buttonSize);
-    bReplaceAll->setIcon(getRealIcon("replaceall"));
+    bReplaceAll->setIcon(getRealIconCached("replaceall"));
 	gridLayout->addWidget(bReplaceAll, 1, 5, 1, 1);
 
 	QFrame* frameReplaceOptions = new QFrame(this);
@@ -265,34 +265,34 @@ QSearchReplacePanel::QSearchReplacePanel(QWidget *p)
 	connect(cReplace->lineEdit(),SIGNAL(textEdited(QString)),SLOT(cReplace_textEdited(QString)));
 
 	// set texts
-	bClose->setToolTip(QApplication::translate("SearchReplace", "Close search/replace panel", 0, QApplication::UnicodeUTF8));
-	cFind->setToolTip(QApplication::translate("SearchReplace", "Text or pattern to search for", 0, QApplication::UnicodeUTF8));
-	bNext->setToolTip(QApplication::translate("SearchReplace", "Find next", 0, QApplication::UnicodeUTF8));
-	bPrevious->setToolTip(QApplication::translate("SearchReplace", "Find previous", 0, QApplication::UnicodeUTF8));
-	bCount->setToolTip(QApplication::translate("SearchReplace", "Count occurences", 0, QApplication::UnicodeUTF8));
-	cReplace->setToolTip(QApplication::translate("SearchReplace", "Replacement text", 0, QApplication::UnicodeUTF8));
-	bReplaceNext->setToolTip(QApplication::translate("SearchReplace", "Replace and find next", 0, QApplication::UnicodeUTF8));
-	bReplacePrevious->setToolTip(QApplication::translate("SearchReplace", "Replace and find previous", 0, QApplication::UnicodeUTF8));
-	bReplaceAll->setToolTip(QApplication::translate("SearchReplace", "Replace all", 0, QApplication::UnicodeUTF8));
+    bClose->setToolTip(tr("Close search/replace panel"));
+    cFind->setToolTip(tr("Text or pattern to search for"));
+    bNext->setToolTip(tr("Find next"));
+    bPrevious->setToolTip(tr("Find previous"));
+    bCount->setToolTip(tr("Count occurences"));
+    cReplace->setToolTip(tr("Replacement text"));
+    bReplaceNext->setToolTip(tr("Replace and find next"));
+    bReplacePrevious->setToolTip(tr("Replace and find previous"));
+    bReplaceAll->setToolTip(tr("Replace all"));
 
-	lbFind->setText(QApplication::translate("SearchReplace", "Find:", 0, QApplication::UnicodeUTF8));
+    lbFind->setText(tr("Find:"));
 	lbFind->setMinimumWidth(lbFind->sizeHint().width());
-	cbCase->setText(QApplication::translate("SearchReplace", "Case", 0, QApplication::UnicodeUTF8));
+    cbCase->setText(tr("Case"));
 	cbCase->setMinimumWidth(cbCase->sizeHint().width());
-	cbWords->setText(QApplication::translate("SearchReplace", "Words", 0, QApplication::UnicodeUTF8));
+    cbWords->setText(tr("Words"));
 	cbWords->setMinimumWidth(cbWords->sizeHint().width());
-	cbRegExp->setText(QApplication::translate("SearchReplace", "Regexp", 0, QApplication::UnicodeUTF8));
+    cbRegExp->setText(tr("Regexp"));
 	cbRegExp->setMinimumWidth(cbRegExp->sizeHint().width());
-	cbHighlight->setText(QApplication::translate("SearchReplace", "Highlight all", 0, QApplication::UnicodeUTF8));
+    cbHighlight->setText(tr("Highlight all"));
 	cbHighlight->setMinimumWidth(cbHighlight->sizeHint().width());
-	cbCursor->setText(QApplication::translate("SearchReplace", "Cursor", 0, QApplication::UnicodeUTF8));
+    cbCursor->setText(tr("Cursor"));
 	cbCursor->setMinimumWidth(cbCursor->sizeHint().width());
-	cbSelection->setText(QApplication::translate("SearchReplace", "Selection", 0, QApplication::UnicodeUTF8));
+    cbSelection->setText(tr("Selection"));
 	cbSelection->setMinimumWidth(cbSelection->sizeHint().width());
-	lbReplace->setText(QApplication::translate("SearchReplace", "Replace:", 0, QApplication::UnicodeUTF8));
-	cbPrompt->setText(QApplication::translate("SearchReplace", "Prompt on replace", 0, QApplication::UnicodeUTF8));
+    lbReplace->setText(tr("Replace:"));
+    cbPrompt->setText(tr("Prompt on replace"));
 	cbPrompt->setMinimumWidth(cbPrompt->sizeHint().width());
-	cbEscapeSeq->setText(QApplication::translate("SearchReplace", "Escape sequences", 0, QApplication::UnicodeUTF8));
+    cbEscapeSeq->setText(tr("Escape sequences"));
 	cbEscapeSeq->setMinimumWidth(cbEscapeSeq->sizeHint().width());
 
 	minimum_width=bClose->sizeHint().width()
