@@ -187,7 +187,7 @@ QList<QPair<QString,QString> > latexToPlainWordReplaceList =
  << QPair<QString, QString> ("\\",""); // eliminating backslash which might remain from accents like \"a ...
 */
 QChar transformCharacter(const QChar& c){
-	switch (c.toAscii()){
+    switch (c.toLatin1()){
 	case 'a': return QChar(0xE4);
 	case 'o': return QChar(0xF6);
 	case 'u': return QChar(0xFC);
@@ -210,7 +210,7 @@ QString latexToPlainWord(const QString& word) {
 			//decode all meta characters starting with a backslash (c++ syntax: don't use an actual backslash there or it creates a multi line comment)
 			i++;
 			if (i>=word.length()) break;
-			switch (word[i].toAscii()) {
+            switch (word[i].toLatin1()) {
 			case '-': //Trennung [separation] (german-babel-package also: \")
 			case '/': //ligatur preventing (german-package also: "|)
 				break;
@@ -232,7 +232,7 @@ QString latexToPlainWord(const QString& word) {
 			//decode all meta characters starting with "
 			i++;
 			if (i>=word.length()) break;
-			switch (word[i].toAscii()) {
+            switch (word[i].toLatin1()) {
 			case '~':
 				result.append('-'); //- ohne Trennung (without separation)
 				break;
@@ -770,7 +770,7 @@ int LatexParser::findContext(QString &line,int &column) const{
     QString eow="\\[]{} $";
 	int i=column;
 	if(i>=line.length())
-		i=line.length()-1;
+		i=line.length();
 	if(i>0)
 		i--; // character left of pos is to be checked
 	else
@@ -872,8 +872,12 @@ LatexParser::ContextType LatexParser::findContext(const QString &line, int colum
 			return Label;
         else if (possibleCommands["%ref"].contains(command))
 			return Reference;
+        else if (possibleCommands["%usepackage"].contains(command))
+            return Package;
         else if (possibleCommands["%cite"].contains(command))
 			return Citation;
+        else if (possibleCommands["%citeExtendedCommand"].contains(command))
+            return Citation_Ext;
         else if (possibleCommands["%graphics"].contains(command))
             return Graphics;
 		else return Option;
@@ -1328,10 +1332,11 @@ LatexReader::NextWordFlag LatexReader::nextWord(bool returnCommands){
 	bool inOption=false;
 	bool inEnv=false;
 	bool inReferenz=false;
+    int inReferenzExt=0;
 	while ((wordStartIndex = nextToken(line, index,inEnv,!inReferenz))!=-1) {
 		word=line.mid(wordStartIndex,index-wordStartIndex);
 		if (word.length()==0) return NW_NOTHING; //should never happen
-		switch (word.at(0).toAscii()) {
+        switch (word.at(0).toLatin1()) {
 		case '%':
 			return NW_COMMENT; //return comment start
 		case '[':
@@ -1347,21 +1352,27 @@ LatexReader::NextWordFlag LatexReader::nextWord(bool returnCommands){
 			if(lp->environmentCommands.contains(lastCommand)) inEnv=true;
 			break; //ignore
 		case '}':
-			if (reference!=-1) {
-				NextWordFlag result = NW_NOTHING;
-                if (lp->possibleCommands["%ref"].contains(lastCommand)) result = NW_REFERENCE;
-                else if (lp->possibleCommands["%label"].contains(lastCommand)) result = NW_LABEL;
-                else if (lp->possibleCommands["%cite"].contains(lastCommand)) result = NW_CITATION;
-				if (result != NW_NOTHING) {
-					wordStartIndex=reference;
-					--index;
-					word=line.mid(reference,index-reference);
-					return result;
-				}
-			}
-			lastCommand="";
-			inOption=false;
-			inEnv=false;
+            if(inReferenzExt>1){
+                inReferenzExt--;
+            }else{
+                if (reference!=-1) {
+                    NextWordFlag result = NW_NOTHING;
+                    if (lp->possibleCommands["%ref"].contains(lastCommand)) result = NW_REFERENCE;
+                    else if (lp->possibleCommands["%label"].contains(lastCommand)) result = NW_LABEL;
+                    else if (lp->possibleCommands["%cite"].contains(lastCommand)) result = NW_CITATION;
+                    else if (lp->possibleCommands["%usepackage"].contains(lastCommand)) result = NW_PACKAGE;
+                    else if (lp->possibleCommands["%citeExtendedCommand"].contains(lastCommand)) result = NW_CITATION;
+                    if (result != NW_NOTHING) {
+                        wordStartIndex=reference;
+                        --index;
+                        word=line.mid(reference,index-reference);
+                        return result;
+                    }
+                }
+                lastCommand="";
+                inOption=false;
+                inEnv=false;
+            }
 			break;//command doesn't matter anymore
 		case '$': case '^': case '&':
 			return NW_COMMAND;
@@ -1373,11 +1384,27 @@ LatexReader::NextWordFlag LatexReader::nextWord(bool returnCommands){
 		case '\\':
 			if (word.length()==1 || !(EscapedChars.contains(word.at(1)) || CharacterAlteringChars.contains(word.at(1)))) {
 				if (returnCommands) return NW_COMMAND;
-                if (lp->possibleCommands["%ref"].contains(word)||lp->possibleCommands["%label"].contains(word)||lp->possibleCommands["%cite"].contains(word)){
+                if (lp->possibleCommands["%ref"].contains(word)||lp->possibleCommands["%label"].contains(word)||lp->possibleCommands["%cite"].contains(word)||lp->possibleCommands["%usepackage"].contains(word)){
 					reference=index; //todo: support for nested brackets like \cite[\xy{\ab{s}}]{miau}
 					lastCommand=word;
 					inReferenz=true;
 				}
+                if (lp->possibleCommands["%citeExtendedCommand"].contains(word)){
+                    QString line;
+                    foreach(line,lp->possibleCommands["%citeExtended"]){
+                        if(line.startsWith(word))
+                            break;
+                        line.clear();
+                    }
+                    if(!line.isEmpty()){
+                        reference=index; //todo: support for nested brackets like \cite[\xy{\ab{s}}]{miau}
+                        lastCommand=word;
+                        line=line.remove(QRegExp("[.*]"));
+                        int pos=line.indexOf("%<bibid%>");
+                        line=line.left(pos);
+                        inReferenzExt=line.count("{");
+                    }
+                }
 				if (lp->optionCommands.contains(lastCommand)||lastCommand.isEmpty()||word=="\\begin"||word=="\\end") {
 					lastCommand=word;
 				}
@@ -1525,6 +1552,43 @@ LatexPackage loadCwlFile(const QString fileName,LatexCompleterConfig *config) {
                 }
                 valid.remove('c');
             }
+            if(valid.contains('C')){ // cite command
+                if(res>-1){
+                    if(!line.contains("%")){
+                        int start=0;
+                        if(line.startsWith("\\begin")){
+                            start=line.indexOf("}")+1;
+                        }
+                        //add placeholders to brackets like () to (%<..%>)
+                        const QString brackets = "{}[]()<>";
+                        int lastOpen = -1, openType = -1;
+                        for (int i = start; i < line.size(); i++) {
+                            int index = brackets.indexOf(line[i]);
+                            if (index>=0) {
+                                if (index % 2 == 0) {
+                                    lastOpen = i;
+                                    openType = index/2;
+                                } else {
+                                    if (lastOpen == -1 || openType != index/2)
+                                        continue;
+                                    if (lastOpen == i-1)
+                                        continue;
+                                    line.insert(lastOpen+1, "%<");
+                                    i+=2;
+                                    line.insert(i, "%>");
+                                    lastOpen = -1;
+                                    i+=2;
+                                }
+                            }
+                        }
+                    }
+                    package.possibleCommands["%citeExtended"] << line.simplified();
+                    if(!line.startsWith("\\begin")) // HANDLE begin extra
+                        package.possibleCommands["%citeExtendedCommand"] << rxCom.cap(1);
+                    hideFromCompletion=true;
+                }
+                valid.remove('C');
+            }
             if(valid.contains('g')){ // definition command
                 if(res>-1){
                     package.possibleCommands["%graphics"] << rxCom.cap(1);
