@@ -43,9 +43,9 @@ QString latexToPlainWord(const QString& word);
 //extracts the section name after \section is removed (brackets removal)
 QString extractSectionName(const QString& word,bool precut=false);
 //closing bracket (opening and closing bracket considered correctly)
-int findClosingBracket(const QString& word,int &start,QChar oc='{',QChar cc='}');
+int findClosingBracket(const QString& word,int &start,QChar oc=QChar('{'),QChar cc=QChar('}'));
 //opening bracket (opening and closing bracket considered correctly), start at "start"
-int findOpeningBracket(const QString& word,int start,QChar oc='{',QChar cc='}');
+int findOpeningBracket(const QString& word,int start,QChar oc=QChar('{'),QChar cc=QChar('}'));
 //replaces character with corresponding LaTeX commands
 QString textToLatex(const QString& text);
 // replaces \texorpdfstring{tex}{pdfString} with pdfString
@@ -112,7 +112,7 @@ public:
 	LatexParser();
 	void init();
 
-    enum ContextType {Unknown, Command, Environment, Label, Reference, Citation, Option, Graphics};
+    enum ContextType {Unknown, Command, Environment, Label, Reference, Citation, Citation_Ext, Option, Graphics,Package};
 	// realizes whether col is in a \command or in a parameter {}
 	int findContext(QString &line, int &column) const;
 	
@@ -182,7 +182,8 @@ struct LatexReader{
 		NW_REFERENCE=5,
 		NW_LABEL=6,
 		NW_CITATION=7,
-		NW_PUNCTATION=8 
+        NW_PUNCTATION=8,
+        NW_PACKAGE=9
 	};
 	
 	//Returns the next word (giving meaning to the nextToken tokens)
