@@ -36,17 +36,21 @@
 #include "unicodeinsertion.h"
 #include "tablemanipulation.h"
 #include "PDFDocument.h"
-#include <QSplitter>
 #include <QSplashScreen>
 #include "session.h"
 #include "qformatfactory.h"
 #include "qlanguagefactory.h"
 #include "qlinemarksinfocenter.h"
 #include "latexstyleparser.h"
+#include "kpathseaParser.h"
 #include "diffoperations.h"
 
+#include <QProgressDialog>
+
 typedef QHash<QString,int> SymbolList;
 
+typedef QSet<QString> StringSet;
+
 enum SVNSTATUS {
 	Unknown=0,
 	Unmanaged,
@@ -60,11 +64,13 @@ class UserMenuDialog;
 class GrammarCheck;
 class FileSelector;
 
+Q_DECLARE_METATYPE(QSet<QString>)
+
 class Texmaker : public QMainWindow {
 	Q_OBJECT
 	
 public:
-	Texmaker(QWidget *parent = 0, Qt::WFlags flags = 0, QSplashScreen *splash = 0);
+    Texmaker(QWidget *parent = 0, Qt::WindowFlags flags = 0, QSplashScreen *splash = 0);
 	~Texmaker();
 	
 	Q_INVOKABLE QString getCurrentFileName(); //returns the absolute file name of the current file or "" if none is opene
@@ -74,7 +80,7 @@ public:
 	bool tobemaximized,tobefullscreen;
 
 public slots:
-    LatexEditorView* load(const QString &f , bool asProject = false, bool hidden = false);
+    LatexEditorView* load(const QString &f , bool asProject = false, bool hidden = false, bool recheck=true);
 	void executeCommandLine(const QStringList& args, bool realCmdLine);
 	void onOtherInstanceMessage(const QString &);  // For messages for the single instance
 	
@@ -111,7 +117,7 @@ private:
 	void setupDockWidgets();
 	void setupToolBars();
 	void createStatusBar();
-	bool FocusEditorForFile(QString f, bool checkTemporaryNames = false);
+	bool ActivateEditorForFile(QString f, bool checkTemporaryNames = false, bool setFocus = true);
 	bool closeAllFilesAsking(); //asks the user and close all files
 	bool canCloseNow(); //asks the user and close all files, and prepares to exit txs
 	void closeEvent(QCloseEvent *e);
@@ -126,7 +132,8 @@ private:
 	
 	//gui
 	TxsTabWidget *EditorTabs;
-	QSplitter *splitter;
+	QSplitter *mainHSplitter;
+	QSplitter *centralVSplitter;
 	QFrame *centralFrame;
 	QToolBar* centralToolBar;
 	CustomWidgetList *leftPanel;
@@ -207,9 +214,10 @@ protected slots:
     void fileSave(const bool saveSilently=false);
 	void fileSaveAll();
 	void fileSaveAll(bool alsoUnnamedFiles, bool alwaysCurrentFile);
+	void fileSaveAs(const QString& fileName = "") { fileSaveAs(fileName, false); }
 private slots:
+	void fileSaveAs(const QString& fileName, const bool saveSilently);
 	void fileNewInternal(QString fileName="");
-    void fileSaveAs(const QString& fileName = "", const bool saveSilently=false);
 protected slots:	
 	void fileClose();
 	void fileCloseAll();
@@ -331,7 +339,7 @@ protected slots:
 	void EditorTabMoved(int from,int to);
 	void editorAboutToChangeByTabClick(LatexEditorView *edFrom, LatexEditorView *edTo);
 
-    void updateStructure(bool initial=false, LatexDocument *doc = 0);
+    void updateStructure(bool initial=false, LatexDocument *doc = 0, bool hidden=false);
 	void ShowStructure();
 	void clickedOnStructureEntry(const QModelIndex & index);
 	void editRemovePlaceHolders();
@@ -410,12 +418,15 @@ protected slots:
 	void AnalyseTextFormDestroyed();
 	void GenerateRandomText();
 	
-	void RealViewLog(bool noTabChange=false);
-	void ViewLog(bool noTabChange=false);
+	bool loadLog();
+	void setLogMarksVisible(bool visible);
+	void clearLogEntriesInEditors();
+	void updateLogEntriesInEditors();
+	void showLog();
+	void ViewLog();
 	void ViewLogOrReRun(LatexCompileResult* result);
-	void DisplayLatexError();
 	bool gotoNearLogEntry(int lt, bool backward, QString notFoundMessage);
-	bool NoLatexErrors();
+	bool HasLatexErrors();
 	bool LogExists();
 	void ClearMarkers();
 	/////
@@ -459,9 +470,9 @@ protected slots:
 	void completerNeedsUpdate();
 	void needUpdatedCompleter();
 	
-	void tabChanged(int i);
+	void outputPageChanged(const QString &id);
 	
-	void gotoLine(int line, int col=0, LatexEditorView *edView = 0, QEditor::MoveFlags mflags = QEditor::Navigation);  // line is 0 based
+	void gotoLine(int line, int col=0, LatexEditorView *edView = 0, QEditor::MoveFlags mflags = QEditor::Navigation, bool setFocus=true);  // line is 0 based
 	bool gotoLine(int line, const QString &fileName);  // line is 0 based, absolute file name
 	void gotoLogEntryEditorOnly(int logEntryNumber);
 	bool gotoLogEntryAt(int newLineNumber);
@@ -532,6 +543,8 @@ private slots:
 	void packageScanCompleted(QString name);
 	void stopPackageParser();
 	void packageParserFinished();
+    void readinAllPackageNames();
+    void packageListReadCompleted(QSet<QString> packages);
 protected:
 	void dragEnterEvent(QDragEnterEvent *event);
 	void dropEvent(QDropEvent *event);
@@ -564,11 +577,12 @@ protected:
 	QString fileFilters;
 	QString selectedFileFilter;
 
-	QWeakPointer<FileSelector> fileSelector;
+	QPointer<FileSelector> fileSelector;
 	
 	bool runBibliographyIfNecessaryEntered;
 	
 	LatexStyleParser *latexStyleParser;
+    KpathSeaParser *packageListReader;
 		
 	QMap<QString,QString> detectedEnvironmentsForHighlighting;
 	
@@ -578,9 +592,13 @@ protected:
 	void restoreBookmarks(LatexEditorView *edView);
 	
     bool completerPreview;
+
+    bool recheckLabels;
 	
 	LatexEditorView *editorViewForLabel(LatexDocument *doc, const QString &label);
 
+    QSet<QString> latexPackageList,currentPackageList;
+
 public:
 	Q_PROPERTY(QString clipboard READ clipboardText WRITE setClipboardText);
 	Q_INVOKABLE QString clipboardText(const QClipboard::Mode& mode = QClipboard::Clipboard) const;
