@@ -2,8 +2,7 @@
 #include "math.h"
 #include "smallUsefulFunctions.h"
 #include "qdocument.h"
-
-Q_DECLARE_METATYPE(QAction*)
+#include "utilsSystem.h"
 
 void adjustScrollBar(QScrollBar *scrollBar, double factor)
 {
@@ -111,129 +110,49 @@ void PreviewWidget::contextMenu(QPoint point) {
 	menu.exec(menuParent->mapToGlobal(point));
 }
 
+OutputViewWidget::OutputViewWidget(QWidget * parent) :
+	TitledPanel(parent),
+	MESSAGES_PAGE("messages"),
+	LOG_PAGE("log"),
+	PREVIEW_PAGE("preview"),
+	SEARCH_RESULT_PAGE("search")
+{
+	setSelectorStyle(TabSelector);
+	mToggleViewAction->setText(tr("Messages / Log File"));
+	mToggleViewAction->setIcon(getRealIcon("logpanel"));
 
 
-
-const int LAYOUT_PAGE_MESSAGES=0;
-const int LAYOUT_PAGE_LOG=1;
-const int LAYOUT_PAGE_ERRORS=2;
-const int LAYOUT_PAGE_PREVIEW=3;
-const int LAYOUT_PAGE_SEARCH=4;
-	
-OutputViewWidget::OutputViewWidget(QWidget * parent): QDockWidget(parent), logModel(0), logpresent(false), tabbedLogView(false){
-    toggleViewAction()->setIcon(getRealIcon("logpanel"));
-
-	logModel = new LatexLogModel(this);//needs loaded line marks
-	searchResultModel = new SearchResultModel(this);
-
-	OutputTable= new QTableView(this);
-	OutputTable2= new QTableView(this); // second table view for tab log view
-
-	// Search Results tree
-	SearchTreeDelegate *searchDelegate=new SearchTreeDelegate(this);
-	OutputTree= new QTreeView(this);
-	OutputTree->setUniformRowHeights(true);
-	OutputTree->setModel(searchResultModel);
-	OutputTree->setItemDelegate(searchDelegate);
-	connect(OutputTree,SIGNAL(clicked(QModelIndex)),this,SLOT(clickedSearchResult(QModelIndex)));
-
+	// messages
 	QFontMetrics fm(QApplication::font());
-	for (int i=0;i<2;i++){ //setup tables
-		QTableView* table=(i==0)?OutputTable:OutputTable2;
-		table->setModel(logModel);
+	OutputMessages = new LogEditor(this);
+	OutputMessages->setFocusPolicy(Qt::ClickFocus);
+	OutputMessages->setMinimumHeight(3*(fm.lineSpacing()+4));
+	OutputMessages->setReadOnly(true);
 
-		table->setSelectionBehavior(QAbstractItemView::SelectRows);
-		table->setSelectionMode(QAbstractItemView::SingleSelection);
-		table->setColumnWidth(0,fm.width("> "));
-		table->setColumnWidth(1,20*fm.width("w"));
-		table->setColumnWidth(2,fm.width("WarningW"));
-		table->setColumnWidth(3,fm.width("Line WWWWW"));
-		table->setColumnWidth(4,20*fm.width("w"));
-		connect(table, SIGNAL(clicked(const QModelIndex &)), this, SLOT(clickedOnLogModelIndex(const QModelIndex &)));
-	
-		table->horizontalHeader()->setStretchLastSection(true);
-		table->setMinimumHeight(5*(fm.lineSpacing()+4));
+	appendPage(new TitledPanelPage(OutputMessages, MESSAGES_PAGE, tr("Messages")), false);
 
-        QAction * act = new QAction(tr("&Copy"),table);
-		connect(act, SIGNAL(triggered()), SLOT(copyMessage()));
-		table->addAction(act);
-        act = new QAction(tr("&Copy all"),table);
-		connect(act, SIGNAL(triggered()), SLOT(copyAllMessages()));
-		table->addAction(act);
-        act = new QAction(tr("&Copy all with line numbers"),table);
-		connect(act, SIGNAL(triggered()), SLOT(copyAllMessagesWithLineNumbers()));
-		table->addAction(act);
-        act = new QAction(tr("&Show in log"),table);
-		connect(act, SIGNAL(triggered()), SLOT(showMessageInLog()));;
-		table->addAction(act);
+	// log / errors
+	logWidget = new LatexLogWidget(this);
 
-		table->setContextMenuPolicy(Qt::ActionsContextMenu);
-	}
-
-	OutputTextEdit = new LogEditor(this);
-	OutputTextEdit->setFocusPolicy(Qt::ClickFocus);
-	OutputTextEdit->setMinimumHeight(3*(fm.lineSpacing()+4));
-	OutputTextEdit->setReadOnly(true);
-	connect(OutputTextEdit, SIGNAL(clickOnLogLine(int)),this,SLOT(gotoLogLine(int)));
-
-	OutputLogTextEdit = new LogEditor(this);
-	OutputLogTextEdit->setFocusPolicy(Qt::ClickFocus);
-	OutputLogTextEdit->setMinimumHeight(3*(fm.lineSpacing()+4));
-	OutputLogTextEdit->setReadOnly(true);
-	connect(OutputLogTextEdit, SIGNAL(clickOnLogLine(int)),this,SLOT(gotoLogLine(int)));
-
-	OutputLayout= new QStackedWidget(this);
-
-	QVBoxLayout* OutputVLayout= new QVBoxLayout(); //contains the widgets for the normal mode (OutputTable + OutputLogTextEdit)
-	OutputVLayout->setSpacing(0);
-	OutputVLayout->setMargin(0);
-
-	// add widget to log view
-	OutputLayout->addWidget(OutputTextEdit);
-
-	OutputVLayout->addWidget(OutputTable);
-	OutputVLayout->addWidget(OutputLogTextEdit);
-	QWidget* tempWidget=new QWidget (this);
-	tempWidget->setLayout(OutputVLayout);
-	OutputLayout->addWidget(tempWidget);
-
-	OutputLayout->addWidget(OutputTable2);
+	TitledPanelPage *page = new TitledPanelPage(logWidget, LOG_PAGE, tr("Log"));
+	page->addToolbarActions(logWidget->displayActions());
+	appendPage(page, false);
 
 	// previewer
 	previewWidget = new PreviewWidget(this);
-	OutputLayout->addWidget(previewWidget);
+	appendPage(new TitledPanelPage(previewWidget, PREVIEW_PAGE, tr("Preview")), false);
 
 	// global search results
-	OutputLayout->addWidget(OutputTree);
+	searchResultModel = new SearchResultModel(this);
 
-	// order for tabbar
-	logViewerTabBar=new QTabBar(this);
-	logViewerTabBar->addTab("m");
-	logViewerTabBar->addTab("l");
-	logViewerTabBar->addTab("e");
-	logViewerTabBar->addTab("p");
-	logViewerTabBar->addTab("s");
-	retranslateUi();
-	logViewerTabBar->hide(); //internal default is non tabbed mode
+	SearchTreeDelegate *searchDelegate=new SearchTreeDelegate(this);
+	OutputSearchTree= new QTreeView(this);
+	OutputSearchTree->setUniformRowHeights(true);
+	OutputSearchTree->setModel(searchResultModel);
+	OutputSearchTree->setItemDelegate(searchDelegate);
+	connect(OutputSearchTree,SIGNAL(clicked(QModelIndex)),this,SLOT(clickedSearchResult(QModelIndex)));
 
-	this->setWidget(OutputLayout);
-
-	connect(logViewerTabBar, SIGNAL(currentChanged(int)),
-	        OutputLayout, SLOT(setCurrentIndex(int)));
-
-	connect(logViewerTabBar, SIGNAL(currentChanged(int)),
-	        this, SIGNAL(tabChanged(int)));
-
-}
-void OutputViewWidget::setTabbedLogView(bool tabbed){
-	tabbedLogView=tabbed;
-	if (tabbed) {
-		this->setTitleBarWidget(logViewerTabBar);
-		OutputTable->hide();
-	} else {
-		this->setTitleBarWidget(0);
-		OutputTable->show();
-	}
+	appendPage(new TitledPanelPage(OutputSearchTree, SEARCH_RESULT_PAGE, tr("Search Results")));
 }
 void OutputViewWidget::previewLatex(const QPixmap& pixmap){
 	previewWidget->previewLatex(pixmap);
@@ -246,8 +165,8 @@ void OutputViewWidget::clickedSearchResult(const QModelIndex& index){
 	emit jumpToSearch(doc,searchResultModel->getLineNumber(index));
 }
 
-LatexLogModel* OutputViewWidget::getLogModel(){
-	return logModel;
+void OutputViewWidget::copySearchResult() {
+	QApplication::clipboard()->setText(OutputSearchTree->currentIndex().data(Qt::DisplayRole).toString());
 }
 
 //copied and modified from qbytearray.cpp
@@ -278,170 +197,57 @@ QByteArray simplifyLineConserving(const QByteArray& ba)
 	return result;
 }
 
-void OutputViewWidget::loadLogFile(const QString &logname, const QString & compiledFileName){
-	OutputLogTextEdit->clear();
-	QFile f(logname);
-	if (f.open(QIODevice::ReadOnly)) {
-
-		if (f.size() > 2*1024*1024 && 
-		    !txsConfirmWarning(tr("The logfile is very large (> %1 MB) are you sure you want to load it?").arg(f.size() / 1024 / 1024))) 
-			return;
-		
-		//QByteArray fullLog = simplifyLineConserving(f.readAll());
-		// TODO: if we want to habe simplification here it has to be smarter.
-		// The above version trims whitespace, which leads to undesired effects due to the 80 char
-		// line width of the log. "line\n 1"  would become "\line\n1" and, when rejoining lines for error/warning detection "line1".
-		// Do we need this or can we just leave the output as it is?
-		QByteArray fullLog = f.readAll();
-		f.close();
-		
-		int sure;
-		QTextCodec * codec = guessEncodingBasic(fullLog, &sure);
-		if (!sure || !codec) codec = QTextCodec::codecForLocale();
-		
-		OutputLogTextEdit->setPlainText(codec->toUnicode(fullLog));
-		
-		logModel->parseLogDocument(OutputLogTextEdit->document(), compiledFileName);
-		
-		logpresent=true;		
-		//update table size
-		OutputTable->resizeColumnsToContents();
-		OutputTable->resizeRowsToContents();
-		OutputTable2->resizeColumnsToContents();
-		OutputTable2->resizeRowsToContents();	
-		
-		selectLogEntry(0,false);
-	} else txsWarning(tr("Failed to load log file \"%1\"").arg(logname));
-}
-bool OutputViewWidget::logPresent(){
-	return logpresent;
-}
 bool OutputViewWidget::isPreviewPanelVisible(){
 	if (!isVisible()) return false;
-	return !tabbedLogView || logViewerTabBar->currentIndex()==LAYOUT_PAGE_PREVIEW;
+	return currentPageId() == PREVIEW_PAGE;
 }
+
 void OutputViewWidget::setMessage(const QString &message){
-	logViewerTabBar->setCurrentIndex(0);
-	OutputTextEdit->setText(message);
+	setCurrentPage(MESSAGES_PAGE);
+	OutputMessages->setText(message);
 }
+
 void OutputViewWidget::insertMessageLine(const QString &message){
-	OutputTextEdit->insertLine(message);
+	OutputMessages->insertLine(message);
 }
-void OutputViewWidget::copy(){
-	if (tabbedLogView) {
-		switch (OutputLayout->currentIndex()) {
-		case LAYOUT_PAGE_MESSAGES: OutputTextEdit->copy(); break;
-		case LAYOUT_PAGE_LOG: OutputLogTextEdit->copy(); break;
-		case LAYOUT_PAGE_ERRORS: copyMessage(); break;
-		case LAYOUT_PAGE_SEARCH: copySearchResult(); break;
-		}
-	} else if (OutputLogTextEdit->hasFocus())
-		OutputLogTextEdit->copy(); 
-	else if (OutputTextEdit->hasFocus())
-		OutputTextEdit->copy(); 
-	else if (OutputTree->hasFocus())
+
+void OutputViewWidget::copy() {
+	QString pageId = currentPageId();
+
+	if (pageId == LOG_PAGE) {
+		logWidget->copy();
+	} else if (pageId == SEARCH_RESULT_PAGE) {
 		copySearchResult();
-	else copyMessage();
+	}
 }
 
 void OutputViewWidget::resetMessages(bool noTabChange){
-	OutputTextEdit->clear();
-	if(!noTabChange) logViewerTabBar->setCurrentIndex(0);
+	OutputMessages->clear();
+	if(!noTabChange) setCurrentPage(MESSAGES_PAGE);
 }
 void OutputViewWidget::resetMessagesAndLog(bool noTabChange){
 	resetMessages(noTabChange);
-	resetLog(noTabChange);
-}
-void OutputViewWidget::resetLog(bool /*noTabChange*/){
-	logpresent=false;
+	logWidget->resetLog();
 }
 void OutputViewWidget::selectLogEntry(int logEntryNumber, bool makeVisible){
-	if (logEntryNumber<0 || logEntryNumber>=logModel->count()) return;
-	if (makeVisible) showErrorListOrLog();
-	OutputTable->scrollTo(logModel->index(logEntryNumber,1),QAbstractItemView::PositionAtCenter);
-	OutputTable->selectRow(logEntryNumber);
-	OutputTable2->scrollTo(logModel->index(logEntryNumber,1),QAbstractItemView::PositionAtCenter);
-	OutputTable2->selectRow(logEntryNumber);
-	OutputLogTextEdit->setCursorPosition(logModel->at(logEntryNumber).logline, 0);
-}
-void OutputViewWidget::showLogOrErrorList(bool noTabChange){
-	if (!isVisible()) show();
-	if (OutputLayout->currentIndex()!=LAYOUT_PAGE_LOG && OutputLayout->currentIndex()!=LAYOUT_PAGE_ERRORS &&!noTabChange)
-		logViewerTabBar->setCurrentIndex(LAYOUT_PAGE_LOG);
-}
-void OutputViewWidget::showErrorListOrLog(){
-	if (!isVisible()) show();
-	if (tabbedLogView) {
-		if (OutputLayout->currentIndex()!=LAYOUT_PAGE_LOG) 
-			logViewerTabBar->setCurrentIndex(LAYOUT_PAGE_ERRORS);
-	} else logViewerTabBar->setCurrentIndex(LAYOUT_PAGE_LOG);
-}
-void OutputViewWidget::showPreview(){
-	if (!isVisible()) show();
-	logViewerTabBar->setCurrentIndex(LAYOUT_PAGE_PREVIEW);
+	if (!logWidget->logEntryNumberValid(logEntryNumber)) return;
+	if (makeVisible) showPage(LOG_PAGE);
+	logWidget->selectLogEntry(logEntryNumber);
 }
 
-void OutputViewWidget::showSearchResults(){
-	if (!isVisible()) show();
-	logViewerTabBar->setCurrentIndex(LAYOUT_PAGE_SEARCH);
-}
-void OutputViewWidget::gotoLogEntry(int logEntryNumber) {
-	if (logEntryNumber<0 || logEntryNumber>=logModel->count()) return;
-	//select entry in table view/log
-	//OutputTable->scrollTo(logModel->index(logEntryNumber,1),QAbstractItemView::PositionAtCenter);
-	//OutputLogTextEdit->setCursorPosition(logModel->at(logEntryNumber).logline, 0);
-	selectLogEntry(logEntryNumber);
-	//notify editor	
-	emit logEntryActivated(logEntryNumber);
+void OutputViewWidget::retranslateUi() {
+	mToggleViewAction->setText(tr("Messages / Log File"));
+	pageFromId(MESSAGES_PAGE)->setTitle(tr("Messages"));
+	pageFromId(LOG_PAGE)->setTitle(tr("Log"));
+	pageFromId(PREVIEW_PAGE)->setTitle(tr("Preview"));
+	pageFromId(SEARCH_RESULT_PAGE)->setTitle(tr("Search Results"));
+	updateTopbar();
 }
 
-void OutputViewWidget::retranslateUi(){
-	logViewerTabBar->setTabText(0,tr("Messages"));
-	logViewerTabBar->setTabText(1,tr("Log File"));
-	logViewerTabBar->setTabText(2,tr("Errors"));
-	logViewerTabBar->setTabText(3,tr("Preview"));
-	logViewerTabBar->setTabText(4,tr("Search Results"));
-}
-
-void OutputViewWidget::clickedOnLogModelIndex(const QModelIndex& index){
-	gotoLogEntry(index.row());
-}
+/*
 void OutputViewWidget::gotoLogLine(int logLine){
-	gotoLogEntry(logModel->logLineNumberToLogEntryNumber(logLine));
-}
-
-void OutputViewWidget::copyMessage(){
-	QModelIndex curMessage = tabbedLogView ? OutputTable2->currentIndex() : OutputTable->currentIndex();
-	if (!curMessage.isValid()) return;
-	curMessage = logModel->index(curMessage.row(), 3);
-	REQUIRE(QApplication::clipboard());
-	QApplication::clipboard()->setText(logModel->data(curMessage, Qt::DisplayRole).toString());
-}
-void OutputViewWidget::copyAllMessages(){
-	QStringList result;
-	for (int i=0;i<logModel->count();i++)
-		result << logModel->data(logModel->index(i, 3), Qt::DisplayRole).toString();
-	REQUIRE(QApplication::clipboard());
-	QApplication::clipboard()->setText(result.join("\n"));
-}
-void OutputViewWidget::copyAllMessagesWithLineNumbers(){
-	QStringList result;
-	for (int i=0;i<logModel->count();i++)
-		result << logModel->data(logModel->index(i, 2), Qt::DisplayRole).toString() +": "+logModel->data(logModel->index(i, 3), Qt::DisplayRole).toString();
-	REQUIRE(QApplication::clipboard());
-	QApplication::clipboard()->setText(result.join("\n"));
-}
-
-void OutputViewWidget::showMessageInLog(){
-	logViewerTabBar->setCurrentIndex(LAYOUT_PAGE_LOG);
-	QModelIndex curMessage = tabbedLogView ? OutputTable2->currentIndex() : OutputTable->currentIndex();
-	if (!curMessage.isValid()) return;
-	gotoLogEntry(curMessage.row());
-}
-
-void OutputViewWidget::copySearchResult(){
-	QApplication::clipboard()->setText(OutputTree->currentIndex().data(Qt::DisplayRole).toString());
-}
+	logWidget->gotoLogEntry(logModel->logLineNumberToLogEntryNumber(logLine));
+}*/
 
 
 void OutputViewWidget::addSearch(QList<QDocumentLineHandle *> lines, QDocument* doc){
@@ -456,18 +262,16 @@ void OutputViewWidget::clearSearch(){
 void OutputViewWidget::setSearchExpression(QString exp,bool isCase,bool isWord,bool isRegExp){
         searchResultModel->setSearchExpression(exp,isCase,isWord,isRegExp);
 }
-QString OutputViewWidget::searchExpression() {
+QString OutputViewWidget::searchExpression() const {
 	return searchResultModel->searchExpression();
 }
 int OutputViewWidget::getNextSearchResultColumn(QString text,int col){
-        return searchResultModel->getNextSearchResultColumn(text,col);
+	return searchResultModel->getNextSearchResultColumn(text,col);
 }
 bool OutputViewWidget::childHasFocus(){
-	return OutputLogTextEdit->hasFocus() 
-	       || (tabbedLogView?OutputTable2->hasFocus():OutputTable->hasFocus())
-	       || OutputTextEdit->hasFocus()
-	       || OutputTree->hasFocus();
-	
+	return logWidget->childHasFocus()
+			|| OutputMessages->hasFocus()
+			|| OutputSearchTree->hasFocus();
 }
 
 void OutputViewWidget::changeEvent(QEvent *event){
@@ -534,7 +338,10 @@ QSize SearchTreeDelegate::sizeHint(const QStyleOptionViewItem &option,
 //====================================================================
 // CustomWidgetList (for left panel)
 //====================================================================
-CustomWidgetList::CustomWidgetList(QWidget* p): 
+
+Q_DECLARE_METATYPE(QAction*)
+
+CustomWidgetList::CustomWidgetList(QWidget* p):
 	QDockWidget(p), toolbox(0), frame(0),stack(0), toolbar(0)
 {
     toggleViewAction()->setIcon(getRealIcon("sidebar"));
