@@ -2,6 +2,7 @@
 #define UTILSSYSTEM_H
 
 #include "mostQtHeaders.h"
+#include <QCache>
 
 #define REQUIRE(x)  do { Q_ASSERT((x)); if (!(x)) return; } while (0)
 #define REQUIRE_RET(x,e) do { Q_ASSERT((x)); if (!(x)) return (e); } while (0)
@@ -12,7 +13,6 @@
 #define LIST_RESERVE(list, count)
 #endif
 
-
 extern const char* TEXSTUDIO_SVN_VERSION;
 
 int getSimplifiedSVNVersion(QString svnVersion = TEXSTUDIO_SVN_VERSION);
@@ -29,8 +29,12 @@ QString findResourceFile(const QString& fileName, bool allowOverride = false, QS
 
 extern bool modernStyle;
 extern bool useSystemTheme;
+
+extern QCache<QString,QIcon>IconCache;
+
 QString getRealIconFile(const QString& icon);
 QIcon getRealIcon(const QString& icon);
+QIcon getRealIconCached(const QString& icon);
 
 //returns if the file is writable (QFileInfo.isWritable works in different ways on Windows and Linux)
 bool isFileRealWritable(const QString& filename);
